Stan Math Library: stan/math/prim/scal/fun/log1p_exp.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log1p_exp.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_LOG1P_EXP_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_LOG1P_EXP_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5 #include <stan/math/prim/scal/fun/log1p.hpp>
6
7 namespace stan {
8 namespace math {
9
42 template <typename T>
43 inline typename boost::math::tools::promote_args<T>::type
44 log1p_exp(const T a) {
45 using std::exp;
46 // like log_sum_exp below with b=0.0; prevents underflow
47 if (a > 0.0)
48 return a + log1p(exp(-a));
49 return log1p(exp(a));
50 }
51
52 }
53 }
54
55 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10
stan::math::log1p_exp
fvar< T > log1p_exp(const fvar< T > &x)
Definition: log1p_exp.hpp:13
stan::math::log1p
fvar< T > log1p(const fvar< T > &x)
Definition: log1p.hpp:16
log1p.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.